---
sidebar_label: types
title: soil.types
---

Types used by soil library

## GetModule Objects

```python
class GetModule(TypedDict)
```

Type for GET modules/:moduleId

## ExperimentStatuses Objects

```python
class ExperimentStatuses(Enum)
```

Experiment Statuses

## Experiment Objects

```python
class Experiment(TypedDict)
```

Type for GET experiments/:experimentId

## Result Objects

```python
class Result(TypedDict)
```

Type for GET results/:resultId

